namespace('ru.geo.unique.device.id');

ru.geo.unique.device.id.Service = (function() {
  var deviceUIDKey, generateUUID, uuid;

  Service.$inject = ['$q'];

  deviceUIDKey = 'device';

  uuid = null;

  generateUUID = function() {
    var d;
    d = performance && performance.now && (performance.now() * 1000);
    if (!d) {
      d = new Date().getTime();
    }
    return 'xxxxxxxxxx-xxxxxxxxxx-4xxxxxxxxx-yxxxxxxxxx-xxxxxxxxxx'.replace(/[xy]/g, function(c) {
      var r;
      r = Math.random() * 16;
      r = (d + r) % 16 | 0;
      d = Math.floor(d / 16);
      if (c === 'x') {
        return r.toString(16);
      } else {
        return (r & 0x3 | 0x8).toString(16);
      }
    });
  };

  function Service(q) {
    this.q = q;
    uuid = localStorage.getItem(deviceUIDKey);
    if (!uuid) {
      uuid = generateUUID();
      localStorage.setItem(deviceUIDKey, uuid);
    }
  }

  Service.prototype.getLastUUID = function() {
    return uuid;
  };

  Service.prototype.getUniqueDeviceID = function() {
    return this.q.resolve(uuid);
  };

  return Service;

})();

namespace('ru.geo.unique.device.id');

angular.module(['ru.geo.unique.device.id', '1.0.0'], []).service('ru.geo.unique.device.id.Service', ru.geo.unique.device.id.Service);

namespace('ru.geo.push.notification');

ru.geo.push.notification.ServicePlatform = {
  FCM_PLATFORM: 'FCM',
  HMS_PLATFORM: 'HMS'
};

ru.geo.push.notification.Service = (function() {
  var FCMPushNotification, HMSPushNotification;

  Service.$inject = ['pushServiceOptions', '_'];

  FCMPushNotification = (function() {
    function FCMPushNotification(pushServiceOptions) {
      this.pushServiceOptions = pushServiceOptions;
    }

    FCMPushNotification.prototype.isPlatformSupportsPushNotifications = function() {
      return (typeof PushNotification !== "undefined" && PushNotification !== null) && ((typeof device !== "undefined" && device !== null ? device.platform : void 0) != null);
    };

    FCMPushNotification.prototype.register = function(options) {
      var push;
      if (!this.isPlatformSupportsPushNotifications()) {
        return options != null ? typeof options.onError === "function" ? options.onError(new Error('Push plugin disabled')) : void 0 : void 0;
      }
      push = PushNotification.init(this.pushServiceOptions);
      push.on('error', function(e) {
        return options != null ? typeof options.onError === "function" ? options.onError(e) : void 0 : void 0;
      });
      push.on('registration', function(data) {
        return options != null ? typeof options.onRegistration === "function" ? options.onRegistration(data) : void 0 : void 0;
      });
      return push.on('notification', function(data) {
        return options != null ? typeof options.onNotification === "function" ? options.onNotification(data) : void 0 : void 0;
      });
    };

    return FCMPushNotification;

  })();

  HMSPushNotification = (function() {
    function HMSPushNotification() {}

    HMSPushNotification.prototype.isPlatformSupportsPushNotifications = function() {
      return (typeof HmsPush !== "undefined" && HmsPush !== null) && ((typeof device !== "undefined" && device !== null ? device.platform : void 0) != null);
    };

    HMSPushNotification.prototype.register = function(options) {
      if (!this.isPlatformSupportsPushNotifications()) {
        return options != null ? typeof options.onError === "function" ? options.onError(new Error('Push plugin disabled')) : void 0 : void 0;
      }
      HmsPush.init();
      HmsPush.getToken().then(function(token) {
        var data;
        data = {
          registrationId: token
        };
        return options != null ? typeof options.onRegistration === "function" ? options.onRegistration(data) : void 0 : void 0;
      })["catch"](function(error) {
        return options != null ? typeof options.onError === "function" ? options.onError(error) : void 0 : void 0;
      });
      return HmsPushEvent.onNotificationOpenedApp(function(result) {
        var data, property;
        if (!result.extras) {
          return;
        }
        data = {
          dtype: 'NOTIFICATION',
          additionalData: {
            foreground: false
          }
        };
        for (property in result.extras) {
          if (property === 'messageId') {
            data.additionalData['meta'] = {
              messageId: result.extras[property]
            };
          } else {
            data.additionalData[property] = result.extras[property];
          }
        }
        return options != null ? typeof options.onNotification === "function" ? options.onNotification(data) : void 0 : void 0;
      });
    };

    return HMSPushNotification;

  })();

  function Service(pushServiceOptions, _) {
    var pushPlatform, pushService;
    this.pushServiceOptions = pushServiceOptions;
    this._ = _;
    pushPlatform = this.pushServiceOptions.platform && this.pushServiceOptions.platform.toUpperCase();
    pushService = (function() {
      switch (pushPlatform) {
        case ru.geo.push.notification.ServicePlatform.FCM_PLATFORM:
          return new FCMPushNotification(this.pushServiceOptions);
        case ru.geo.push.notification.ServicePlatform.HMS_PLATFORM:
          return new HMSPushNotification();
        default:
          return new FCMPushNotification(this.pushServiceOptions);
      }
    }).call(this);
    this.isPlatformSupportsPushNotifications = function() {
      return pushService.isPlatformSupportsPushNotifications();
    };
    this.register = function(options) {
      return pushService.register(options);
    };
  }

  return Service;

})();

namespace('ru.geo.push.registration');

ru.geo.push.registration.Service = (function() {
  Service.$inject = ['pushServiceOptions', '$http', 'app-platform', 'pushRegistrationOptions', 'appConfigService'];

  function Service(pushServiceOptions, http, appPlatform, pushRegistrationOptions, appConfigService) {
    this.pushServiceOptions = pushServiceOptions;
    this.http = http;
    this.appPlatform = appPlatform;
    this.pushRegistrationOptions = pushRegistrationOptions;
    this.appConfigService = appConfigService;
  }

  Service.prototype._getRegistrationUrl = function() {
    var baseUrl, ref;
    baseUrl = (ref = this.pushRegistrationOptions) != null ? ref.baseUrl : void 0;
    if (this.appPlatform.isAndroid) {
      return "" + this.appConfigService.serverName + baseUrl + "/gcm/register/" + this.pushServiceOptions.android.senderID;
    }
    if (this.appPlatform.isIos) {
      return "" + this.appConfigService.serverName + baseUrl + "/apple/register/" + this.pushServiceOptions.android.senderID;
    }
  };

  Service.prototype.registerIn4geo = function(registrationId) {
    var failure, success;
    if (this.appConfigService.pushPlatform === ru.geo.push.notification.ServicePlatform.HMS_PLATFORM) {
      return;
    }
    success = function(response) {
      return console.log("Device registered successfully with message: '" + (JSON.stringify(response)) + "'");
    };
    failure = function(e) {
      return console.error("Device registration failed: '" + ((e != null ? e.data : void 0) || JSON.stringify(e)) + "'");
    };
    return this.http({
      method: 'POST',
      url: this._getRegistrationUrl(),
      headers: {
        'Content-Type': 'application/x-www-form-urlencoded'
      },
      data: "registrationId=" + (encodeURIComponent(registrationId))
    }).then(success, failure);
  };

  return Service;

})();

namespace('ru.geo.push.notification');

ru.geo.push.notification.Provider = (function() {
  function Provider() {}

  Provider.prototype.setPushServiceOptions = function(pushServiceOptions) {
    return this.pushServiceOptions = pushServiceOptions;
  };

  Provider.prototype.$get = [
    '$log', '$http', '_', function($log, $http, _) {
      if (!this.pushServiceOptions) {
        $log.error('Push service options not set');
      }
      return new ru.geo.push.notification.Service(this.pushServiceOptions, _);
    }
  ];

  return Provider;

})();

namespace('ru.geo.push.registration');

ru.geo.push.registration.Provider = (function() {
  function Provider() {}

  Provider.prototype.setPushServiceRegistrationOptions = function(pushRegistrationOptions) {
    return this.pushRegistrationOptions = pushRegistrationOptions;
  };

  Provider.prototype.setPushServiceOptions = function(pushServiceOptions) {
    return this.pushServiceOptions = pushServiceOptions;
  };

  Provider.prototype.setAppPlatform = function(appPlatform) {
    return this.appPlatform = appPlatform;
  };

  Provider.prototype.$get = [
    '$log', '$http', 'appConfigService', function($log, $http, appConfigService) {
      if (!this.pushRegistrationOptions) {
        $log.error('Push registration options not set');
      }
      if (!this.pushServiceOptions) {
        $log.error('Push service options not set');
      }
      if (!this.appPlatform) {
        $log.error('App platform not set');
      }
      return new ru.geo.push.registration.Service(this.pushServiceOptions, $http, this.appPlatform, this.pushRegistrationOptions, appConfigService);
    }
  ];

  return Provider;

})();

namespace('ru.geo.push.notification');

angular.module(['ru.geo.push.notification', '1.0.0'], ['ru.geo.underscore']).provider('ru.geo.push.notification.Service', ru.geo.push.notification.Provider);

namespace('ru.geo.push.registration');

angular.module(['ru.geo.push.registration', '1.0.0'], ['ru.geo.app.config.dynamic']).provider('ru.geo.push.registration.Service', ru.geo.push.registration.Provider);

namespace('ru.geo.open.native.settings');

ru.geo.open["native"].settings.Service = (function() {
  Service.$inject = ['$q'];

  Service.prototype.APPLICATION_DETAILS = 'application_details';

  function Service(q) {
    this.q = q;
    if (!this.hasSupport()) {
      if (typeof console !== "undefined" && console !== null) {
        console.warn('Platform not support opening native settings');
      }
    }
  }

  Service.prototype.hasSupport = function() {
    var ref, ref1;
    return (typeof window !== "undefined" && window !== null ? (ref = window.cordova) != null ? (ref1 = ref.plugins) != null ? ref1.settings : void 0 : void 0 : void 0) != null;
  };

  Service.prototype.open = function(settingConstant) {
    var deferred, onError, onSuccess, ref, ref1, settings;
    settings = typeof window !== "undefined" && window !== null ? (ref = window.cordova) != null ? (ref1 = ref.plugins) != null ? ref1.settings : void 0 : void 0 : void 0;
    if (settings == null) {
      return this.q.reject(new Error('Platform not support opening native settings'));
    }
    deferred = this.q.defer();
    onSuccess = function() {
      return deferred.resolve();
    };
    onError = function() {
      return deferred.reject("Failed to open settings " + settingConstant);
    };
    settings.open(settingConstant, onSuccess, onError);
    return deferred.promise;
  };

  return Service;

})();

namespace('ru.geo.open.native.settings');

angular.module(['ru.geo.open.native.settings', '1.0.0'], []).service('ru.geo.open.native.settings.Service', ru.geo.open["native"].settings.Service);

namespace('ru.geo.platform.permissions');

ru.geo.platform.permissions.Service = (function() {
  Service.$inject = ['$q', '_'];

  function Service(q, _) {
    this.q = q;
    this._ = _;
    if (!this.hasSupport()) {
      if (typeof console !== "undefined" && console !== null) {
        console.warn('Platform not support "check" and "request" permissions');
      }
    }
  }

  Service.prototype.hasSupport = function() {
    var ref;
    return (typeof cordova !== "undefined" && cordova !== null ? (ref = cordova.plugins) != null ? ref.permissions : void 0 : void 0) != null;
  };

  Service.prototype.permissions = function() {
    var ref;
    return typeof cordova !== "undefined" && cordova !== null ? (ref = cordova.plugins) != null ? ref.permissions : void 0 : void 0;
  };

  Service.prototype.hasPermission = function(permission) {
    var deferred, onError, onSuccess, permissions, ref;
    permissions = typeof cordova !== "undefined" && cordova !== null ? (ref = cordova.plugins) != null ? ref.permissions : void 0 : void 0;
    if (permissions == null) {
      return this.q.reject(new Error('Platform not support "check" and "request" permissions'));
    }
    deferred = this.q.defer();
    onSuccess = function(status) {
      return deferred.resolve(status.hasPermission);
    };
    onError = function() {
      return deferred.reject(new Error("Unexpected error when check permission " + permission));
    };
    permissions.checkPermission(permission, onSuccess, onError);
    return deferred.promise;
  };

  Service.prototype.requestPermission = function(permission) {
    var deferred, onError, onSuccess, permissions, ref;
    permissions = typeof cordova !== "undefined" && cordova !== null ? (ref = cordova.plugins) != null ? ref.permissions : void 0 : void 0;
    if (permissions == null) {
      return this.q.reject(new Error('Platform not support "check" and "request" permissions'));
    }
    deferred = this.q.defer();
    onSuccess = function(status) {
      return deferred.resolve(status.hasPermission);
    };
    onError = function() {
      return deferred.reject(new Error("Unexpected error when requesting permission " + permission));
    };
    permissions.requestPermission(permission, onSuccess, onError);
    return deferred.promise;
  };

  return Service;

})();

namespace('ru.geo.platform.permissions');

angular.module(['ru.geo.platform.permissions', '1.0.0'], []).service('ru.geo.platform.permissions.Service', ru.geo.platform.permissions.Service);

namespace('ru.geo.screenshot');

ru.geo.screenshot.Service = (function() {
  Service.$inject = ['$q'];

  function Service(q) {
    this.q = q;
  }

  Service.prototype.capture = function(filename, extension, quality) {
    var callback, deferred, ref;
    if (extension == null) {
      extension = 'jpg';
    }
    if (quality == null) {
      quality = '100';
    }
    deferred = this.q.defer();
    if ((typeof navigator !== "undefined" && navigator !== null ? (ref = navigator.screenshot) != null ? ref.save : void 0 : void 0) == null) {
      deferred.reject(new Error('No bindings to take screenshot!'));
      return deferred.promise;
    }
    callback = function(error, res) {
      if (error != null) {
        return deferred.reject(error);
      }
      return deferred.resolve(res);
    };
    navigator.screenshot.save(callback, extension, quality, filename);
    return deferred.promise;
  };

  return Service;

})();

namespace('ru.geo.screenshot');

angular.module(['ru.geo.screenshot', '1.0.0'], ['ru.geo.state']).service('ru.geo.screenshot.Service', ru.geo.screenshot.Service);

namespace('ru.geo.auto.fill.form');

ru.geo.auto.fill.form.Directive = function($localstorage) {
  var AUTO_FILL_SELECTOR, LOCALE_STORAGE_PREFIX, generateStorageKey, loadFormData, resetForm, saveValueInLocaleStorage, setValueInElement, submitForm;
  LOCALE_STORAGE_PREFIX = 'auto_fill_form_';
  AUTO_FILL_SELECTOR = '[auto-fill]';
  submitForm = function(e) {
    var autoFillElement, autoFillElements, i, len, results;
    autoFillElements = angular.element(e.currentTarget).find(AUTO_FILL_SELECTOR);
    results = [];
    for (i = 0, len = autoFillElements.length; i < len; i++) {
      autoFillElement = autoFillElements[i];
      results.push(saveValueInLocaleStorage(angular.element(autoFillElement)));
    }
    return results;
  };
  resetForm = function(e) {
    var el, elements, form, i, len, ref;
    e.preventDefault();
    form = angular.element(e.currentTarget);
    elements = form.find(':input');
    ref = elements.not('[type=\'submit\']');
    for (i = 0, len = ref.length; i < len; i++) {
      el = ref[i];
      el = angular.element(el);
      el.val('');
      if (el.checked) {
        el.checked = false;
      }
    }
    return loadFormData(form.find(AUTO_FILL_SELECTOR));
  };
  generateStorageKey = function(item) {
    var elementName;
    elementName = item.attr('name');
    if (elementName) {
      return LOCALE_STORAGE_PREFIX + elementName;
    }
  };
  saveValueInLocaleStorage = function(item) {
    var key, value;
    value = item.val();
    key = generateStorageKey(item);
    if ((value != null) && (key != null)) {
      return $localstorage.set(key, value);
    }
  };
  loadFormData = function(elements) {
    var element, i, len, results;
    results = [];
    for (i = 0, len = elements.length; i < len; i++) {
      element = elements[i];
      results.push(setValueInElement(angular.element(element)));
    }
    return results;
  };
  setValueInElement = function(item) {
    var key;
    key = generateStorageKey(item);
    if (key != null) {
      return item.val($localstorage.get(key));
    }
  };
  return {
    restrict: 'E',
    replace: false,
    link: function(scope, element) {
      var autoFillElements;
      autoFillElements = element.find(AUTO_FILL_SELECTOR);
      loadFormData(autoFillElements);
      if (!(autoFillElements.length > 0)) {
        return;
      }
      element.on('submit', submitForm);
      return element.on('reset', resetForm);
    }
  };
};

ru.geo.auto.fill.form.Directive.$inject = ['$localstorage'];

namespace('ru.geo.auto.fill.form');

angular.module(['ru.geo.auto.fill.form', '1.0.0'], []).directive('form', ru.geo.auto.fill.form.Directive);

namespace('ru.geo.streaming.video.link');

ru.geo.streaming.video.link.Directive = function(log) {
  return {
    restrict: 'AE',
    transclude: false,
    scope: {
      streamUrl: '@',
      streamSuccess: '&onSuccess',
      streamError: '&onError'
    },
    link: function(scope, element) {
      return new ru.geo.streaming.video.link.DirectiveLink().link(scope, element, log);
    }
  };
};

ru.geo.streaming.video.link.Directive.$inject = ['$log'];

ru.geo.streaming.video.link.DirectiveLink = (function() {
  function DirectiveLink() {}

  DirectiveLink.prototype.link = function(scope, element, log) {
    var callbackError, callbackSucces, msg, ref, ref1, watch;
    callbackError = function(e) {
      log.error("error on playing " + scope.streamUrl + ": " + (JSON.stringify(e)));
      return typeof scope.streamError === "function" ? scope.streamError(e) : void 0;
    };
    if (!((((ref = window.plugins) != null ? (ref1 = ref.streamingMedia) != null ? ref1.playVideo : void 0 : void 0) != null) && (scope.streamUrl != null))) {
      msg = 'No plugin for streaming playback (cordova-plugin-streaming-media)';
      callbackError(msg);
      return;
    }
    callbackSucces = function() {
      log.debug("successfully played " + scope.streamUrl);
      return typeof scope.streamSuccess === "function" ? scope.streamSuccess() : void 0;
    };
    callbackSucces();
    watch = function() {
      var options;
      options = {
        successCallback: callbackSucces,
        errorCallback: callbackError
      };
      return window.plugins.streamingMedia.playVideo(scope.streamUrl, options);
    };
    return element.on('click', function(e) {
      return watch();
    });
  };

  return DirectiveLink;

})();

namespace('ru.geo.streaming.video.link');

angular.module(['ru.geo.streaming.video.link', '1.0.0'], []).directive('ruGeoStreamingVideoLink', ru.geo.streaming.video.link.Directive);

namespace('ru.geo.gaid');

ru.geo.gaid.Service = (function() {
  var isSupportedAndroid, isSupportedHMSAds, isSupportedIos, resolveAndroidGAID, resolveHMSAds, resolveIosIdfa;

  Service.$inject = ['$q'];

  isSupportedAndroid = function() {
    var ref, ref1;
    return ((ref = window.plugins) != null ? (ref1 = ref.gaidWrapperPlugin) != null ? ref1.getGoogleAdvertisingId : void 0 : void 0) != null;
  };

  isSupportedIos = function() {
    var plugins, ref;
    plugins = typeof cordova !== "undefined" && cordova !== null ? (ref = cordova.require('cordova/plugin_list')) != null ? ref.metadata : void 0 : void 0;
    return (plugins != null ? plugins['com.ios.cordova-idfa'] : void 0) != null;
  };

  isSupportedHMSAds = function() {
    return window.HMSAds != null;
  };

  resolveIosIdfa = function(deferred) {
    var error, success;
    success = function(idfa) {
      if (idfa) {
        return deferred.resolve(idfa);
      }
      return deferred.reject(new Error('IDFA not supported on this device'));
    };
    error = function() {
      return deferred.reject(new Error('Cannot get IDFA'));
    };
    return cordova.exec(success, error, 'CDVIdfa', 'advertisingIdentifier', []);
  };

  resolveHMSAds = function(deferred) {
    HMSAds.init();
    return HMSAds.getAdvertisingIdInfo().then(function(result) {
      if (result.id) {
        return deferred.resolve(result.id);
      }
      return deferred.reject(new Error('HMSAds not supported on this device'));
    })["catch"](function() {
      return deferred.reject(new Error('Cannot get HMSAds'));
    });
  };

  resolveAndroidGAID = function(deferred) {
    var error, success;
    success = function(arg) {
      var gaid;
      gaid = (arg != null ? arg : {}).gaid;
      if (gaid) {
        return deferred.resolve(gaid);
      }
      return deferred.reject(new Error('GoogleAdvertisingId not supported on this device'));
    };
    error = function() {
      return deferred.reject(new Error('Cannot get GoogleAdvertisingId'));
    };
    return window.plugins.gaidWrapperPlugin.getGoogleAdvertisingId(success, error);
  };

  function Service(q) {
    var deferred;
    deferred = q.defer();
    this.getGaid = function() {
      return deferred.promise;
    };
    if (isSupportedIos()) {
      resolveIosIdfa(deferred);
      return;
    }
    if (isSupportedAndroid()) {
      resolveAndroidGAID(deferred);
      return;
    }
    if (isSupportedHMSAds()) {
      resolveHMSAds(deferred);
      return;
    }
    deferred.reject(new Error('AdvertisingId not supported'));
    return;
  }

  Service.prototype.isSupported = function() {
    return isSupportedIos() || isSupportedAndroid() || isSupportedHMSAds();
  };

  return Service;

})();

namespace('ru.geo.gaid');

angular.module(['ru.geo.gaid', '1.0.0'], []).service('ru.geo.gaid.Service', ru.geo.gaid.Service);

namespace('ru.geo.analytics');

ru.geo.analytics.Service = (function() {
  var sentryPromise;

  Service.$inject = ['$q', 'sentry-dsn', 'app-name', 'app-version', 'app-id', '$log', 'pushServiceOptions'];

  sentryPromise = null;

  function Service(q, sentryDsn, appName, appVersion, appId, log, pushServiceOptions) {
    var deferred, onDeviceReady;
    this.log = log;
    deferred = q.defer();
    sentryPromise = deferred.promise;
    sentryPromise["catch"](function() {
      return this.log.error('[Sentry] Not init');
    });
    onDeviceReady = (function(_this) {
      return function() {
        var Sentry;
        Sentry = typeof cordova !== "undefined" && cordova !== null ? typeof cordova.require === "function" ? cordova.require('sentry-cordova.Sentry') : void 0 : void 0;
        if (!Sentry) {
          sentryPromise.reject();
        }
        Sentry.init({
          dsn: sentryDsn,
          initialScope: {
            tags: {
              appId: appId,
              appName: appName,
              pushPlatform: pushServiceOptions.platform,
              appVersion: appVersion
            }
          }
        });
        return deferred.resolve(Sentry);
      };
    })(this);
    document.addEventListener('deviceready', onDeviceReady, false);
    window.onerror = (function(_this) {
      return function(msg, url, line, column, errorObject) {
        var description, stack;
        stack = (errorObject != null ? errorObject.stack : void 0) || '???';
        description = {
          error: msg,
          url: url,
          line: line,
          column: column,
          stack: stack
        };
        _this.sendException(JSON.stringify(description));
        return false;
      };
    })(this);
  }

  Service.prototype.sendException = function(description) {
    this.log.error("[Sentry] send exception: " + description);
    return sentryPromise != null ? sentryPromise.then(function(sentry) {
      return sentry.captureException(new Error(description));
    }) : void 0;
  };

  return Service;

})();

namespace('ru.geo.app.config.dynamic');

ru.geo.app.config.dynamic.Service = (function() {
  var REQUEST_UPDATE_SERVER_TIMEOUT, SERVER_UPDATED_EVENT, STORAGE_SERVER_NAME, STORAGE_UPDATE_SERVER_NAME, UPDATE_SERVER_NAME_EVENT, getInitAppUrl, getServerName, getUpdateDomainUrl, getUrlFromQueryParam, getUrlLogOpenPushNotification;

  Service.$inject = ['app-name', 'bundle-id', 'app-version', 'app-id', 'app-platform', 'app-platform-name', 'custom-header', 'pushRegistrationOptions', 'pushServiceOptions', 'ajax-timeout', 'index-page', 'server-name', 'params', 'update-domain-url', '$q'];

  STORAGE_SERVER_NAME = 'serverName';

  STORAGE_UPDATE_SERVER_NAME = 'updDomainUrl';

  REQUEST_UPDATE_SERVER_TIMEOUT = 5000;

  SERVER_UPDATED_EVENT = 'serverUpdated';

  UPDATE_SERVER_NAME_EVENT = 'updateServerName';

  getUrlFromQueryParam = function(param) {
    return param && decodeURIComponent(param);
  };

  getUrlLogOpenPushNotification = function(serverName, params) {
    var url;
    url = getUrlFromQueryParam(params['url-log-open-push-notification']);
    return url || (serverName + "/xhr/mobile/openpushmessage");
  };

  getInitAppUrl = function(serverName, params) {
    var url;
    url = getUrlFromQueryParam(params['initAppUrl']);
    return url || (serverName + "/xhr/mobile/init/");
  };

  getServerName = function(defaultServerName) {
    return localStorage.getItem(STORAGE_SERVER_NAME) || defaultServerName;
  };

  getUpdateDomainUrl = function(defaultUrl) {
    return localStorage.getItem(STORAGE_UPDATE_SERVER_NAME) || defaultUrl;
  };

  function Service(appName, bundleId, appVersion, appId, appPlatform, appPlatformName, customHeader, pushRegistrationOptions, pushServiceOptions, ajaxTimeout, defaultIndexPage, defaultServerName, params1, defaultUpdateDomainUrl, q) {
    var requestUpdateDomain;
    this.appName = appName;
    this.bundleId = bundleId;
    this.appVersion = appVersion;
    this.appId = appId;
    this.appPlatform = appPlatform;
    this.appPlatformName = appPlatformName;
    this.customHeader = customHeader;
    this.pushRegistrationOptions = pushRegistrationOptions;
    this.pushServiceOptions = pushServiceOptions;
    this.ajaxTimeout = ajaxTimeout;
    this.params = params1;
    this.updateDomainUrl = getUpdateDomainUrl(defaultUpdateDomainUrl);
    this.serverName = getServerName(defaultServerName);
    this.senderId = this.pushServiceOptions.android.senderID;
    this.indexPage = defaultIndexPage;
    this.pushPlatform = this.pushServiceOptions.platform;
    requestUpdateDomain = (function(_this) {
      return function() {
        var deferred, hash, onError, success;
        deferred = q.defer();
        if (_this.updateDomainUrl) {
          success = function(response) {
            var e, json;
            try {
              json = JSON.parse(response);
              if (json.url) {
                _this.setServerName(json.url);
              }
            } catch (error) {
              e = error;
              console.error('Does not parse response [update domain url]');
            }
            return deferred.resolve(_this);
          };
          onError = function() {
            console.error('Update domain url does not respond');
            return deferred.resolve(this);
          };
          hash = Date.now();
          sys.xhr.getWithTimeout(_this.updateDomainUrl + "?" + hash, success, onError, REQUEST_UPDATE_SERVER_TIMEOUT);
        } else {
          deferred.resolve(_this);
        }
        return deferred.promise;
      };
    })(this);
    this.initUrls = function() {
      this.urlLogOpenPushNotification = getUrlLogOpenPushNotification(this.serverName, this.params);
      return this.initAppUrl = getInitAppUrl(this.serverName, this.params);
    };
    this.setUpdateDomainUrl = function(url) {
      if (this.updateDomainUrl !== url) {
        localStorage.setItem(STORAGE_UPDATE_SERVER_NAME, url);
        this.updateDomainUrl = url;
        return requestUpdateDomain();
      }
    };
    this.setServerName = function(newServer) {
      var customEvent, data;
      localStorage.setItem(STORAGE_SERVER_NAME, newServer);
      if (this.serverName !== newServer) {
        this.serverName = newServer;
        this.initUrls();
        customEvent = document.createEvent('CustomEvent');
        data = {
          newServer: newServer
        };
        customEvent.initCustomEvent(SERVER_UPDATED_EVENT, true, true, data);
        return window.dispatchEvent(customEvent);
      }
    };
    window.addEventListener(UPDATE_SERVER_NAME_EVENT, requestUpdateDomain);
    this.initUrls();
    this.promiseFinishInitialise = requestUpdateDomain();
  }

  return Service;

})();

namespace('ru.geo.app.init');

ru.geo.app.init.OrganizationCssJsService = (function() {
  var addScriptPromise, addStylePromise;

  OrganizationCssJsService.$inject = ['ru.geo.app.init.resources.timeout', '$q', 'appConfigService', '$timeout'];

  addStylePromise = function(url, container, q, resourcesLoadTimeout, timeout) {
    var deferred, rejectedByTimeout, styleElement;
    deferred = q.defer();
    rejectedByTimeout = function() {
      return deferred.reject(url + " rejected by timeout " + resourcesLoadTimeout);
    };
    timeout(rejectedByTimeout, resourcesLoadTimeout, false);
    styleElement = document.createElement('link');
    styleElement.rel = 'stylesheet';
    styleElement.href = url;
    styleElement.onerror = function(error) {
      return deferred.reject(error);
    };
    styleElement.onload = function() {
      return deferred.resolve('ok');
    };
    container.appendChild(styleElement);
    return deferred.promise;
  };

  addScriptPromise = function(url, container, q, resourcesLoadTimeout, timeout) {
    var deferred, rejectedByTimeout, scriptElement;
    deferred = q.defer();
    rejectedByTimeout = function() {
      return deferred.reject(url + " rejected by timeout " + resourcesLoadTimeout);
    };
    timeout(rejectedByTimeout, resourcesLoadTimeout, false);
    scriptElement = document.createElement('script');
    scriptElement.type = 'text/javascript';
    scriptElement.src = url;
    scriptElement.onerror = function(error) {
      return deferred.reject(error);
    };
    scriptElement.onload = function() {
      return deferred.resolve('ok');
    };
    container.appendChild(scriptElement);
    return deferred.promise;
  };

  function OrganizationCssJsService(resourcesLoadTimeout, q, appConfigService, timeout) {
    this.promiseLoad = function(arg) {
      var container, cssUrls, expectedPromises, i, j, jsUrls, len, len1, url;
      jsUrls = arg.jsUrls, cssUrls = arg.cssUrls;
      expectedPromises = [];
      container = document.getElementsByTagName('head')[0];
      if (jsUrls != null ? jsUrls.length : void 0) {
        for (i = 0, len = jsUrls.length; i < len; i++) {
          url = jsUrls[i];
          expectedPromises.push(addScriptPromise(url, container, q, resourcesLoadTimeout, timeout));
        }
      }
      if (cssUrls != null ? cssUrls.length : void 0) {
        for (j = 0, len1 = cssUrls.length; j < len1; j++) {
          url = cssUrls[j];
          expectedPromises.push(addStylePromise(url, container, q, resourcesLoadTimeout, timeout));
        }
      }
      return q.all(expectedPromises);
    };
  }

  return OrganizationCssJsService;

})();

namespace('ru.geo.app.init');

ru.geo.app.init.CurrentBranch = (function() {
  var STORAGE_NAME, abstractOrganizationId, branchData;

  CurrentBranch.$inject = [];

  STORAGE_NAME = 'aoId';

  abstractOrganizationId = null;

  branchData = null;

  function CurrentBranch() {
    abstractOrganizationId = parseInt(localStorage.getItem(STORAGE_NAME)) || null;
  }

  CurrentBranch.prototype.getId = function() {
    return abstractOrganizationId;
  };

  CurrentBranch.prototype.set = function(newBranchData) {
    if (!newBranchData) {
      return;
    }
    branchData = newBranchData;
    abstractOrganizationId = newBranchData.abstractOrganizationId;
    localStorage.setItem(STORAGE_NAME, abstractOrganizationId);
    return branchData;
  };

  CurrentBranch.prototype.get = function() {
    return branchData;
  };

  return CurrentBranch;

})();

namespace('ru.geo.f7.history');

ru.geo.f7.history.Service = (function() {
  Service.$inject = ['$rootScope', '$interval', 'updateInterval'];

  function Service(rootScope, interval, updateInterval) {
    this.rootScope = rootScope;
    this.interval = interval;
    this.updateInterval = updateInterval;
  }

  Service.prototype.bind = function() {};

  Service.prototype.canGoBack = function() {
    return false;
  };

  Service.prototype.notifyBack = function() {};

  return Service;

})();

var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };

namespace('ru.geo.push');

ru.geo.push.InitializerService = (function() {
  var OPEN_PUSH_TIMEOUT, STORAGE_SAVED_PUSH;

  STORAGE_SAVED_PUSH = 'pushData';

  OPEN_PUSH_TIMEOUT = 300;

  InitializerService.$inject = ['$q', 'appConfigService', '$http', 'T', 'ru.geo.push.notification.Service', '$log', 'ru.geo.analytics.Service', 'ru.geo.push.registration.Service', 'ru.geo.app.init.CurrentBranch'];

  function InitializerService(q, appConfigService, http, T, pushService, log, analytics, pushRegistrationService) {
    this.q = q;
    this.appConfigService = appConfigService;
    this.http = http;
    this.T = T;
    this.pushService = pushService;
    this.log = log;
    this.analytics = analytics;
    this.pushRegistrationService = pushRegistrationService;
    this.initialize = bind(this.initialize, this);
  }

  InitializerService.prototype.initialize = function(promiseReadyToShowPush, getDeviceInfoData, viewMain, framework7, currentBranch, SELECT_BRANCH_EVENT, domWindow, PAGE_INIT_EVENT_NAME) {
    var applyUpdatedServerInPush, confirmOpenUrlInternal, deferred, openInternalUrlFn, openPush;
    openInternalUrlFn = (function(_this) {
      return function(options) {
        var data;
        _this.log.log("Open push url: " + options.internalUrl);
        data = {
          abstractOrganizationId: currentBranch.getId(),
          messageId: options.messageId,
          dtype: options.dtype,
          deviceInfo: getDeviceInfoData()
        };
        _this.http.post(_this.appConfigService.urlLogOpenPushNotification, {}, {
          params: data
        });
        viewMain.addRouteByUrl(options.internalUrl);
        return viewMain.router.navigate({
          name: options.internalUrl
        });
      };
    })(this);
    openPush = function(options) {
      var customEvent, data, prepareOpenPush, ref;
      if (currentBranch.getId() && currentBranch.getId() === options.aoid) {
        return openInternalUrlFn(options);
      } else if (!currentBranch.getId()) {
        prepareOpenPush = function(e) {
          domWindow.off(PAGE_INIT_EVENT_NAME, prepareOpenPush);
          openPush = function() {
            return openInternalUrlFn(options);
          };
          return setTimeout(openPush, OPEN_PUSH_TIMEOUT);
        };
        domWindow.on(PAGE_INIT_EVENT_NAME, prepareOpenPush);
        customEvent = document.createEvent('CustomEvent');
        data = {
          id: options.aoid
        };
        customEvent.initCustomEvent(SELECT_BRANCH_EVENT, true, true, data);
        return window.dispatchEvent(customEvent);
      } else {
        currentBranch.set({
          abstractOrganizationId: options.aoid
        });
        localStorage.setItem(STORAGE_SAVED_PUSH, JSON.stringify(options));
        return typeof window !== "undefined" && window !== null ? (ref = window.location) != null ? ref.reload(true) : void 0 : void 0;
      }
    };
    confirmOpenUrlInternal = (function(_this) {
      return function(options) {
        var cancelBtn, dialog, openBtn;
        options.message || (options.message = _this.T('Новое уведомление'));
        cancelBtn = {
          text: _this.T('Отмена')
        };
        openBtn = {
          text: _this.T('Перейти'),
          bold: true,
          onClick: function() {
            return openPush(options);
          }
        };
        dialog = framework7.dialog.create({
          title: options.message,
          buttons: [cancelBtn, openBtn]
        });
        return dialog.open();
      };
    })(this);
    if (!this.pushService.isPlatformSupportsPushNotifications()) {
      return this.q.reject(new Error("Platform " + (typeof device !== "undefined" && device !== null ? device.platform : void 0) + " didn't support push notifications"));
    }
    deferred = this.q.defer();
    applyUpdatedServerInPush = (function(_this) {
      return function(additionalData) {
        if (additionalData.newServer) {
          _this.appConfigService.setServerName(additionalData.newServer);
        }
        if (additionalData.newUpDomainUrl) {
          return _this.appConfigService.setUpdateDomainUrl(additionalData.newUpDomainUrl);
        }
      };
    })(this);
    this.appConfigService.promiseFinishInitialise.then((function(_this) {
      return function() {
        var err, savedPushData, savedPushJson;
        _this.pushService.register({
          onError: function(e) {
            var error;
            deferred.reject(e);
            error = (e != null ? e.message : void 0) || JSON.stringify(e);
            _this.log.log("Error during push registration: " + error);
            return _this.analytics.sendException("Error during push registration: " + error);
          },
          onRegistration: function(data) {
            _this.log.log("Push registration success: " + (JSON.stringify(data)) + " with: " + (JSON.stringify(_this.appConfigService.pushServiceOptions)));
            if (data != null) {
              deferred.resolve({
                registrationId: data.registrationId
              });
              return _this.pushRegistrationService.registerIn4geo(data.registrationId);
            } else {
              return deferred.reject(new Error('Push service onRegistration event with empty data'));
            }
          },
          onNotification: function(data) {
            var additionalData, options, ref;
            _this.log.log("Push notification: " + (JSON.stringify(data)));
            additionalData = (data != null ? data.additionalData : void 0) || {};
            applyUpdatedServerInPush(additionalData);
            options = {
              internalUrl: additionalData.openInternalUrl,
              messageId: (ref = additionalData.meta) != null ? ref.messageId : void 0,
              message: data != null ? data.message : void 0,
              dtype: 'NOTIFICATION',
              aoid: parseInt(additionalData.aoid) || _this.appConfigService.appId
            };
            if (options.internalUrl != null) {
              return promiseReadyToShowPush.then(function() {
                if (additionalData.foreground) {
                  options.dtype = 'FOREGROUND';
                  confirmOpenUrlInternal(options);
                  return;
                }
                return openPush(options);
              });
            }
          }
        });
        savedPushJson = localStorage.getItem(STORAGE_SAVED_PUSH);
        if (savedPushJson) {
          localStorage.removeItem(STORAGE_SAVED_PUSH);
          try {
            savedPushData = JSON.parse(savedPushJson);
          } catch (error1) {
            err = error1;
            _this.log.error("Load push error: " + err);
            savedPushData = null;
          }
          return promiseReadyToShowPush.then(function() {
            if (savedPushData) {
              return openInternalUrlFn(savedPushData);
            }
          });
        }
      };
    })(this));
    return deferred.promise;
  };

  return InitializerService;

})();

var slice = [].slice;

namespace('ru.geo.ppm.ui.test');

ru.geo.ppm.ui.test.Logger = (function() {
  Logger.$inject = ['$log'];

  function Logger(logService) {
    this.logService = logService;
  }

  Logger.prototype.log = function(message) {
    return this.logService.log("[UI Test] " + message);
  };

  Logger.prototype.error = function(message) {
    return this.logService.error("[UI Test] Error: " + message);
  };

  return Logger;

})();

ru.geo.ppm.ui.test.InternalUrl = (function() {
  function InternalUrl(url1, log) {
    this.url = url1;
    this.log = log;
  }

  InternalUrl.prototype.execute = function(view) {
    this.log.log("Loading URL " + this.url);
    return view.router.loadPage({
      url: this.url,
      ignoreCache: true,
      reload: true,
      animatePages: false,
      pushState: false
    });
  };

  InternalUrl.prototype.ready = function() {
    return this.log.log("URL " + this.url + " is ready");
  };

  return InternalUrl;

})();

ru.geo.ppm.ui.test.InternalUrlRunner = (function() {
  function InternalUrlRunner(dom7, internalUrls, log, timeout, q, viewMain) {
    var internalUrlTests, ref, url;
    this.dom7 = dom7;
    this.log = log;
    this.timeout = timeout;
    this.viewMain = viewMain;
    internalUrlTests = (function() {
      var i, len, results;
      results = [];
      for (i = 0, len = internalUrls.length; i < len; i++) {
        url = internalUrls[i];
        results.push(new ru.geo.ppm.ui.test.InternalUrl(url, this.log));
      }
      return results;
    }).call(this);
    this.pagesTests = [];
    (ref = this.pagesTests).push.apply(ref, internalUrlTests);
    this.deferred = q.defer();
  }

  InternalUrlRunner.prototype.pageInitEvent = function() {
    var nextPageTest, ref, rest, runNext;
    ref = this.pagesTests, nextPageTest = ref[0], rest = 2 <= ref.length ? slice.call(ref, 1) : [];
    this.pagesTests = rest;
    runNext = (function(_this) {
      return function() {
        var ref1;
        if ((ref1 = _this.currentPageTest) != null) {
          ref1.ready();
        }
        _this.currentPageTest = nextPageTest;
        if (_this.currentPageTest == null) {
          _this.deferred.resolve();
          return;
        }
        return _this.currentPageTest.execute(_this.viewMain);
      };
    })(this);
    this.timeout(runNext, 2000);
    return this.deferred.promise;
  };

  InternalUrlRunner.prototype.whenDone = function() {
    return this.deferred.promise;
  };

  return InternalUrlRunner;

})();

ru.geo.ppm.ui.test.Menu = (function() {
  function Menu(side1, f7, timeout, screenshotService1, appName1) {
    this.side = side1;
    this.f7 = f7;
    this.timeout = timeout;
    this.screenshotService = screenshotService1;
    this.appName = appName1;
  }

  Menu.prototype.execute = function() {
    this.f7.openPanel(this.side);
    return this.timeout(4000).then((function(_this) {
      return function() {
        return _this.screenshotService.capture(_this.appName + "_" + _this.side)["catch"](function(e) {});
      };
    })(this));
  };

  return Menu;

})();

ru.geo.ppm.ui.test.MenuRunner = (function() {
  function MenuRunner(sides, timeout, f7, q, screenshotService, appName) {
    var side;
    this.timeout = timeout;
    this.f7 = f7;
    this.deferred = q.defer();
    this.tests = (function() {
      var i, len, results;
      results = [];
      for (i = 0, len = sides.length; i < len; i++) {
        side = sides[i];
        results.push(new ru.geo.ppm.ui.test.Menu(side, this.f7, this.timeout, screenshotService, appName));
      }
      return results;
    }).call(this);
  }

  MenuRunner.prototype.run = function() {
    var ref, rest, test;
    ref = this.tests, test = ref[0], rest = 2 <= ref.length ? slice.call(ref, 1) : [];
    if (test == null) {
      this.deferred.resolve();
      return;
    }
    test.execute().then((function(_this) {
      return function() {
        _this.f7.closePanel();
        _this.tests = rest;
        return _this.run();
      };
    })(this));
    return this.deferred.promise;
  };

  return MenuRunner;

})();

var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };

namespace('ru.geo.master');

ru.geo.master.Controller = (function() {
  var API_VERSION, BACK_EVENT, CUSTOM_PAGE_INIT_EVENT, SELECT_BRANCH_EVENT, UPDATE_CHECK_INTERVAL_IN_MINUTES, statusBarTheme;

  CUSTOM_PAGE_INIT_EVENT = 'onPageInit';

  SELECT_BRANCH_EVENT = 'on-select-branch';

  BACK_EVENT = 'framework7RouteBack';

  UPDATE_CHECK_INTERVAL_IN_MINUTES = 30;

  API_VERSION = '1.0';

  Controller.$inject = ['$q', '$compile', '$scope', '$document', 'dom7', 'ru.geo.analytics.Service', '$log', '$injector', '$timeout', 'T', '$http', 'ru.geo.unique.device.id.Service', 'appConfigService', 'ru.geo.gaid.Service', 'ru.geo.platform.permissions.Service', 'ru.geo.open.native.settings.Service', 'ru.geo.app.init.CurrentBranch', 'ru.geo.push.InitializerService', 'ru.geo.app.init.OrganizationCssJsService', 'ru.geo.master.f7.theme.colors', 'ru.geo.master.f7.default.theme', 'bundle-id', 'app-name', 'app-version', 'app-id', 'app-platform-name', 'framework7-version', 'ajax-timeout', 'custom-header', '_'];

  statusBarTheme = null;

  function Controller(q, compile, scope, document1, dom7, analytics, log, injector, timeout, T, http, uniqueDeviceIdService, appConfigService, gaidService, platformPermissionsService, openNativeSettingsService, currentBranch, pushInitializerService, organizationCssJsService, themeColors, defaultTheme, bundleId, appName, appVersion, appId, appPlatformName, framework7Version, ajaxTimeout, customHeader, _1) {
    this.q = q;
    this.compile = compile;
    this.scope = scope;
    this.document = document1;
    this.dom7 = dom7;
    this.analytics = analytics;
    this.log = log;
    this.injector = injector;
    this.timeout = timeout;
    this.T = T;
    this.http = http;
    this.uniqueDeviceIdService = uniqueDeviceIdService;
    this.appConfigService = appConfigService;
    this.platformPermissionsService = platformPermissionsService;
    this.openNativeSettingsService = openNativeSettingsService;
    this.currentBranch = currentBranch;
    this.pushInitializerService = pushInitializerService;
    this.organizationCssJsService = organizationCssJsService;
    this.themeColors = themeColors;
    this.defaultTheme = defaultTheme;
    this.bundleId = bundleId;
    this.appName = appName;
    this.appVersion = appVersion;
    this.appId = appId;
    this.appPlatformName = appPlatformName;
    this.framework7Version = framework7Version;
    this.ajaxTimeout = ajaxTimeout;
    this.customHeader = customHeader;
    this._ = _1;
    this.showBadRequestModal = bind(this.showBadRequestModal, this);
    this.getDeviceInfoData = bind(this.getDeviceInfoData, this);
    this.processed = bind(this.processed, this);
    this.initializeFramework7 = bind(this.initializeFramework7, this);
    this.getPromiseLoadIndexPage = bind(this.getPromiseLoadIndexPage, this);
    this.gaid = null;
    statusBarTheme = new ru.geo.theme.StatusBarTheme(this.themeColors, this.defaultTheme);
    this.appConfigService.promiseFinishInitialise.then((function(_this) {
      return function() {
        var domWindow, promiseGaid, promiseLoadIndexPage, promiseRegistrationId, promiseUniqueDeviceID;
        domWindow = _this.dom7(window);
        promiseUniqueDeviceID = _this.uniqueDeviceIdService.getUniqueDeviceID().then(function(uuid) {
          return _this.log.log("Unique device id is: " + uuid);
        })["catch"](function(e) {
          return _this.log.log("Can't determine unique device id: " + ((e != null ? e.message : void 0) || JSON.stringify(e)));
        });
        promiseGaid = gaidService.getGaid().then(function(gaid) {
          return _this.gaid = gaid;
        })["catch"](function(e) {
          return _this.log.log((e != null ? e.message : void 0) || e);
        });
        _this.initializeFramework7();
        promiseLoadIndexPage = _this.getPromiseLoadIndexPage(domWindow);
        promiseLoadIndexPage.then(function() {
          return $('body').removeClass('with-splash');
        });
        promiseRegistrationId = _this.pushInitializerService.initialize(promiseLoadIndexPage, _this.getDeviceInfoData, _this.viewMain, _this.framework7, _this.currentBranch, SELECT_BRANCH_EVENT, domWindow, CUSTOM_PAGE_INIT_EVENT).then(function(data) {
          return _this.registrationId = data.registrationId;
        })["catch"](function(e) {
          return _this.log.log("Can't get registrationId: " + ((e != null ? e.message : void 0) || JSON.stringify(e)));
        });
        return _this.q.all([promiseUniqueDeviceID, promiseRegistrationId, promiseGaid])["finally"](function() {
          return _this.initializeApp()["catch"](function(error) {
            var message;
            message = "Error init app. Response: " + (JSON.stringify(error));
            _this.analytics.sendException(message);
            return _this.showBadRequestModal(function() {
              var ref;
              return typeof window !== "undefined" && window !== null ? (ref = window.location) != null ? ref.reload(true) : void 0 : void 0;
            });
          });
        });
      };
    })(this));
  }

  Controller.prototype.initializeApp = function() {
    var data, url;
    url = this.appConfigService.initAppUrl;
    data = {
      aoId: this.appConfigService.appId,
      platformName: this.appConfigService.appPlatformName,
      bundleId: this.appConfigService.bundleId,
      senderId: this.appConfigService.senderId,
      appVersion: this.appConfigService.appVersion,
      apiVersion: API_VERSION
    };
    this.log.log("Init App data: " + (JSON.stringify(data)));
    return this.http.post(url, {}, {
      params: data
    }).then((function(_this) {
      return function(response) {
        var message, ref, responseData;
        responseData = response.data;
        _this.log.log("Init App response: " + (JSON.stringify(responseData)));
        if ((ref = responseData.mobileBranches) != null ? ref.length : void 0) {
          return _this.initAppData(responseData);
        } else {
          message = "Server not responded branches. Request: " + (JSON.stringify(data)) + " Response: " + (JSON.stringify(responseData));
          _this.analytics.sendException(message);
          return _this.showBadRequestModal(function() {
            var ref1;
            return typeof window !== "undefined" && window !== null ? (ref1 = window.location) != null ? ref1.reload(true) : void 0 : void 0;
          });
        }
      };
    })(this));
  };

  Controller.prototype.initAppData = function(data) {
    var bootData, branch;
    bootData = data.bootData || {
      js: [],
      css: []
    };
    this.branches = data.mobileBranches;
    branch = this.getCurrentBranch(data);
    statusBarTheme.setBranchesSelectorColor(bootData.statusbarColor);
    if (branch) {
      return this.loadBranch(branch, bootData);
    } else {
      return this.loadBranchesSelector(bootData);
    }
  };

  Controller.prototype.getCurrentBranch = function(data) {
    if (data.mobileBranches.length === 1) {
      return data.mobileBranches[0];
    } else {
      return _.find(data.mobileBranches, (function(_this) {
        return function(branch) {
          return branch.abstractOrganizationId === _this.currentBranch.getId();
        };
      })(this));
    }
  };

  Controller.prototype.loadBranch = function(branch, bootData) {
    var cssJsPromise;
    this.currentBranch.set(branch);
    cssJsPromise = this.organizationCssJsService.promiseLoad({
      jsUrls: bootData.js.concat(branch.urls.js),
      cssUrls: bootData.css.concat(branch.urls.css)
    })["catch"]((function(_this) {
      return function(error) {
        var message;
        message = "Unable to resolve personal page css/js, error: '" + ((error != null ? error.message : void 0) || JSON.stringify(error)) + "'";
        _this.analytics.sendException(message);
        return _this.q.reject(error);
      };
    })(this));
    return cssJsPromise.then((function(_this) {
      return function() {
        var route;
        if (typeof window !== "undefined" && window !== null) {
          if (typeof window.onF7Run === "function") {
            window.onF7Run(_this.framework7, _this.viewMain);
          }
        }
        statusBarTheme.setCurrentBranchColorByThemeAndApply(branch.theme);
        _this.updateTheme(branch.theme);
        _this.beforeLoadMainPage();
        _this.framework7.params.iosSwipeBack = false;
        route = _this.viewMain.addRouteByUrl(branch.mainPage);
        return _this.viewMain.router.navigate(route.path, {
          ignoreCache: true,
          reloadCurrent: true
        });
      };
    })(this))["catch"]((function(_this) {
      return function(error) {
        return _this.showBadRequestModal(function() {
          var ref;
          return typeof window !== "undefined" && window !== null ? (ref = window.location) != null ? ref.reload(true) : void 0 : void 0;
        });
      };
    })(this));
  };

  Controller.prototype.loadBranchesSelector = function(bootData) {
    var cssJsPromise, message;
    if (bootData.url == null) {
      message = 'Unable to resolve url for select branch';
      this.analytics.sendException(message);
      this.showBadRequestModal(function() {
        var ref;
        return typeof window !== "undefined" && window !== null ? (ref = window.location) != null ? ref.reload(true) : void 0 : void 0;
      });
      return;
    }
    cssJsPromise = this.organizationCssJsService.promiseLoad({
      jsUrls: bootData.js,
      cssUrls: bootData.css
    })["catch"]((function(_this) {
      return function(error) {
        message = "Unable to resolve boot personal page css/js, error: '" + ((error != null ? error.message : void 0) || JSON.stringify(error)) + "'";
        _this.analytics.sendException(message);
        return _this.q.reject(error);
      };
    })(this));
    return cssJsPromise.then((function(_this) {
      return function() {
        var route;
        statusBarTheme.applyBranchesSelectorColor();
        route = _this.viewMain.addRouteByUrl(bootData.url);
        return _this.viewMain.router.navigate(route, {
          ignoreCache: true,
          reloadCurrent: true
        });
      };
    })(this))["catch"]((function(_this) {
      return function(error) {
        return _this.showBadRequestModal(function() {
          var ref;
          return typeof window !== "undefined" && window !== null ? (ref = window.location) != null ? ref.reload(true) : void 0 : void 0;
        });
      };
    })(this));
  };

  Controller.prototype.beforeLoadMainPage = function() {
    return this.initApp = (function(_this) {
      return function(leftMenu, extendsBlock) {
        _this.initApp = function() {};
        _this.leftMenuRef = leftMenu;
        return _this.scope.$applyAsync(function() {
          _this.leftMenu = leftMenu;
          return _this.extendsBlock = extendsBlock;
        });
      };
    })(this);
  };

  Controller.prototype.getThemeColor = function(theme) {
    return theme && this.themeColors[theme];
  };

  Controller.prototype.updateTheme = function(data) {
    var ref;
    if (!data) {
      return;
    }
    return this.theme = {
      colorClass: data.color,
      layoutClass: data.layoutTheme,
      colorClassV4: 'color-' + data.color,
      layoutClassV4: (ref = data.layoutTheme) != null ? ref.replace('layout', 'theme') : void 0
    };
  };

  Controller.prototype.getPromiseLoadIndexPage = function(domWindow) {
    var deferred, onPageLoad;
    deferred = this.q.defer();
    onPageLoad = (function(_this) {
      return function() {
        deferred.resolve();
        _this.scope.$applyAsync();
        return domWindow.off(CUSTOM_PAGE_INIT_EVENT, onPageLoad);
      };
    })(this);
    domWindow.on(CUSTOM_PAGE_INIT_EVENT, onPageLoad);
    return deferred.promise;
  };

  Controller.prototype.initializeFramework7 = function() {
    var customErrorCallback, customErrorHandler, customNavigateBack, goBack, navigateBack;
    customErrorCallback = null;
    customErrorHandler = null;
    this.framework7 = new Framework7({
      id: this.bundleId,
      name: this.appName,
      root: '#app',
      version: this.appVersion,
      theme: this.appConfigService.appPlatform.isAndroid ? 'md' : 'ios',
      initOnDeviceReady: true,
      smartSelect: {
        closeOnSelect: true,
        pageBackLinkText: 'Назад'
      },
      clicks: {
        externalLinks: '.external'
      },
      touch: {
        fastClicksDistanceThreshold: 10,
        fastClicksDelayBetweenClicks: 50,
        fastClicksExclude: '.without-fast-click',
        tapHold: true,
        tapHoldDelay: 750,
        tapHoldPreventClicks: true,
        activeState: true,
        activeStateElements: 'a, button, label, span, .actions-button',
        materialRipple: true
      },
      panel: {
        swipe: 'left'
      },
      on: {
        pageBeforeIn: (function(_this) {
          return function(event, page) {
            return _this.compile(event.pageEl)(_this.scope);
          };
        })(this)
      }
    });
    this.framework7.customHeaders = function() {
      return {};
    };
    this.framework7.request.setup({
      beforeOpen: (function(_this) {
        return function(xhr, options) {
          var base64, bundle, key, ref, value;
          bundle = {
            appVersion: _this.appVersion,
            appId: _this.appId,
            platform: _this.appPlatformName,
            pushPlatform: _this.appConfigService.pushPlatform,
            framework7Version: _this.framework7Version
          };
          base64 = btoa(JSON.stringify(bundle));
          options.timeout || (options.timeout = _this.ajaxTimeout);
          options.headers || (options.headers = {});
          options.headers[_this.customHeader] = base64;
          ref = _this.framework7.customHeaders(xhr, options);
          for (key in ref) {
            value = ref[key];
            options.headers[key] = value;
          }
          options.xhrFields || (options.xhrFields = {});
          options.xhrFields['withCredentials'] = true;
          return true;
        };
      })(this),
      beforeSend: (function(_this) {
        return function(xhr, options) {
          _this.framework7.preloader.show();
          return true;
        };
      })(this),
      success: (function(_this) {
        return function(response, status, xhr) {
          return _this.processed(response, xhr.requestUrl);
        };
      })(this),
      complete: (function(_this) {
        return function(xhr, stautus) {
          return _this.framework7.preloader.hide();
        };
      })(this),
      error: (function(_this) {
        return function(xhr, status) {
          var description;
          description = {
            message: 'Framework7.ajaxError',
            response: xhr.response,
            responseText: xhr.responseText,
            requestUrl: xhr.requestUrl,
            readyState: xhr.readyState,
            status: xhr.status,
            headers: JSON.stringify(xhr.headers),
            method: xhr.method
          };
          _this.analytics.sendException(JSON.stringify(description));
          _this.framework7.preloader.hide();
          if (_.isFunction(customErrorCallback)) {
            _this.scope.$applyAsync(function() {
              return customErrorCallback = null;
            });
            return customErrorCallback(xhr);
          }
          if (typeof customErrorHandler === "function" ? customErrorHandler(xhr) : void 0) {
            return;
          }
          return _this.showBadRequestModal(function() {
            var route;
            route = _this.viewMain.addRouteByUrl(xhr.requestUrl);
            return _this.viewMain.router.navigate(route.path, {
              ignoreCache: true,
              reloadCurrent: true
            });
          });
        };
      })(this)
    });
    this.viewMain = this.framework7.views.create('.view-main', {
      dynamicNavbar: true
    });
    this.framework7.addRouteByUrl = (function(_this) {
      return function(url, options) {
        var i, index, len, path, removeList, route;
        if (options == null) {
          options = {};
        }
        if (!url) {
          return;
        }
        removeList = _this._.filter(_this.viewMain.routes, function(value) {
          return value.name === url || value.path === url;
        });
        for (i = 0, len = removeList.length; i < len; i++) {
          route = removeList[i];
          index = _this.viewMain.routes.indexOf(route);
          _this.viewMain.routes.splice(index, 1);
        }
        path = "/" + (btoa(url)) + "/";
        if (!options.content) {
          options.url = url;
        }
        options.name = url;
        options.path = path;
        _this.viewMain.routes.push(options);
        return options;
      };
    })(this);
    this.framework7.updateLink = (function(_this) {
      return function(element) {
        var items;
        if (element == null) {
          element = document;
        }
        items = $(element).find('.item-link, .link, .button');
        items.push($(element));
        return _this._.chain(items).map(function(value) {
          return $(value);
        }).filter(function(value) {
          var href;
          href = value.attr('href');
          return href && href !== '#' && value.is('[link-internal]');
        }).filter(function(value) {
          return !value.attr('original-href');
        }).each(function(value) {
          var originalHref, route;
          originalHref = value.attr('href');
          route = _this.framework7.addRouteByUrl(originalHref, value.data());
          return value.attr('href', route.path).attr('original-href', originalHref);
        });
      };
    })(this);
    this.viewMain.addRouteByUrl = this.framework7.addRouteByUrl;
    this.framework7.bindCustomErrorHandler = function(newHandler) {
      return customErrorHandler = newHandler;
    };
    this.framework7.init();
    this.framework7.preloader.show();
    (function(_this) {
      return (function() {
        var originFuncBack, originFuncLoad;
        originFuncLoad = _this.viewMain.router.navigate;
        _this.viewMain.router.navigate = function(parameters, options) {
          customErrorCallback = options != null ? options.onError : void 0;
          return originFuncLoad != null ? originFuncLoad.apply(this, arguments) : void 0;
        };
        originFuncBack = _this.viewMain.router.back;
        return _this.viewMain.router.back = function(parameters, options) {
          customErrorCallback = options != null ? options.onError : void 0;
          return originFuncBack != null ? originFuncBack.apply(this, arguments) : void 0;
        };
      });
    })(this)();
    goBack = (function(_this) {
      return function() {
        var ref;
        if (_this.viewMain.router.history.length > 1) {
          return _this.viewMain.router.back();
        } else {
          return typeof navigator !== "undefined" && navigator !== null ? (ref = navigator.app) != null ? typeof ref.exitApp === "function" ? ref.exitApp() : void 0 : void 0 : void 0;
        }
      };
    })(this);
    customNavigateBack = null;
    navigateBack = function() {
      var customBack;
      if (customNavigateBack) {
        customBack = customNavigateBack;
        return customNavigateBack({
          customBack: customBack,
          goBack: goBack
        });
      } else {
        return goBack();
      }
    };
    Dom7(document).on('click', '.js-f7-back', navigateBack);
    document.addEventListener('backbutton', navigateBack);
    window.addEventListener(BACK_EVENT, navigateBack);
    this.framework7.bindHistoryEvent = function(customBack) {
      return customNavigateBack = customBack;
    };
    return this.initEventListener();
  };

  Controller.prototype.initEventListener = function() {
    var getBaseEventData;
    getBaseEventData = (function(_this) {
      return function() {
        return {
          injector: _this.injector,
          framework7: _this.framework7,
          viewMain: _this.viewMain,
          leftMenu: _this.leftMenuRef,
          deviceInfo: _this.getDeviceInfoData(),
          branches: _this.branches,
          services: {
            openNativeSettingsService: _this.openNativeSettingsService,
            platformPermissionsService: _this.platformPermissionsService,
            uniqueDeviceIdService: _this.uniqueDeviceIdService,
            statusBarTheme: statusBarTheme
          }
        };
      };
    })(this);
    this.framework7.on('pageInit', (function(_this) {
      return function(page) {
        var customEvent, data;
        _this.framework7.updateLink(page.el);
        _this.framework7.updateLink(_this.framework7.navbar.getElByPage(page.el));
        customEvent = document.createEvent('CustomEvent');
        data = getBaseEventData();
        data.page = page;
        customEvent.initCustomEvent(CUSTOM_PAGE_INIT_EVENT, true, true, data);
        return window.dispatchEvent(customEvent);
      };
    })(this));
    this.dom7(document).on('page:afterin', function(e) {
      var customEvent, data;
      customEvent = document.createEvent('CustomEvent');
      data = getBaseEventData();
      data.page = e.detail;
      customEvent.initCustomEvent('onPageAfterAnimation', true, true, data);
      return window.dispatchEvent(customEvent);
    });
    return window.addEventListener(SELECT_BRANCH_EVENT, (function(_this) {
      return function(e) {
        var cssJsPromise, currentBranchId, ref, ref1, route, selectedBranch;
        if (((ref = e.detail) != null ? ref.id : void 0) == null) {
          _this.log.log("Event:" + SELECT_BRANCH_EVENT + ". Id undefined");
          return;
        }
        selectedBranch = _.find(_this.branches || [], function(branch) {
          return branch.abstractOrganizationId === e.detail.id;
        });
        if (!selectedBranch) {
          _this.log.log("Select not exists branch " + e.detail.id);
          return;
        }
        currentBranchId = _this.currentBranch.getId();
        _this.framework7.params.panel.swipe = 'left';
        _this.framework7.params.iosSwipeBack = true;
        if (currentBranchId) {
          if (currentBranchId === selectedBranch.abstractOrganizationId) {
            route = _this.viewMain.addRouteByUrl(selectedBranch.mainPage);
            return _this.viewMain.router.navigate(route, {
              ignoreCache: true,
              reloadCurrent: true
            });
          } else {
            _this.currentBranch.set(selectedBranch);
            return typeof window !== "undefined" && window !== null ? (ref1 = window.location) != null ? ref1.reload(true) : void 0 : void 0;
          }
        } else {
          _this.currentBranch.set(selectedBranch);
          return cssJsPromise = _this.organizationCssJsService.promiseLoad({
            jsUrls: selectedBranch.urls.js,
            cssUrls: selectedBranch.urls.css
          }).then(function() {
            if (typeof window !== "undefined" && window !== null) {
              if (typeof window.onF7Run === "function") {
                window.onF7Run(_this.framework7, _this.viewMain);
              }
            }
            statusBarTheme.setCurrentBranchColorByThemeAndApply(selectedBranch.theme);
            _this.updateTheme(selectedBranch.theme);
            _this.beforeLoadMainPage();
            route = _this.viewMain.addRouteByUrl(selectedBranch.mainPage);
            return _this.viewMain.router.navigate(route, {
              ignoreCache: true,
              reloadCurrent: true
            });
          })["catch"](function(error) {
            var message;
            message = "Unable to resolve personal page css/js, error: '" + ((error != null ? error.message : void 0) || JSON.stringify(error)) + "'";
            _this.analytics.sendException(message);
            return _this.showBadRequestModal(function() {
              var ref2;
              return typeof window !== "undefined" && window !== null ? (ref2 = window.location) != null ? ref2.reload(true) : void 0 : void 0;
            });
          });
        }
      };
    })(this));
  };

  Controller.prototype.initApp = function() {};

  Controller.prototype.processed = function(content, url) {
    var compiledContent, el, extendsBlock, leftMenu;
    if (!content) {
      this.framework7.removeFromCache(url);
      return content;
    }
    if (this.leftMenu) {
      return;
    }
    compiledContent = this.compile(content)(this.scope);
    leftMenu = angular.element((function() {
      var i, len, results;
      results = [];
      for (i = 0, len = compiledContent.length; i < len; i++) {
        el = compiledContent[i];
        if (el.tagName === 'LEFT-MENU') {
          results.push(el);
        }
      }
      return results;
    })());
    this.framework7.updateLink(leftMenu);
    leftMenu.remove();
    extendsBlock = angular.element((function() {
      var i, len, results;
      results = [];
      for (i = 0, len = compiledContent.length; i < len; i++) {
        el = compiledContent[i];
        if (el.tagName === 'MOBILE-EXTENDS') {
          results.push(el);
        }
      }
      return results;
    })());
    this.framework7.updateLink(extendsBlock);
    extendsBlock.remove();
    this.initApp(leftMenu, extendsBlock);
    return compiledContent;
  };

  Controller.prototype.getDeviceInfoData = function() {
    var data;
    data = {
      senderId: this.appConfigService.senderId,
      registrationId: this.registrationId,
      pushPlatform: this.appConfigService.pushPlatform,
      uuid: this.uniqueDeviceIdService.getLastUUID()
    };
    if (this.gaid) {
      data.gaid = this.gaid;
    }
    return data;
  };

  Controller.prototype.showBadRequestModal = function(retryCallback) {
    var modal, modalButtons, ref;
    modalButtons = [];
    this.framework7.preloader.hide();
    if ((typeof navigator !== "undefined" && navigator !== null ? (ref = navigator.app) != null ? ref.exitApp : void 0 : void 0) != null) {
      modalButtons.push({
        text: this.T('Выйти'),
        onClick: function() {
          var ref1;
          return typeof navigator !== "undefined" && navigator !== null ? (ref1 = navigator.app) != null ? typeof ref1.exitApp === "function" ? ref1.exitApp() : void 0 : void 0 : void 0;
        }
      });
    }
    modalButtons.push({
      text: this.T('Продолжить'),
      onClick: function() {
        return retryCallback();
      }
    });
    modal = this.framework7.dialog.create({
      title: this.T('Ошибка подключения'),
      text: this.T('Для работы приложению необходимо подключение к интернету.' + ' Пожалуйста, восстановите подключение для продолжения.'),
      buttons: modalButtons
    });
    return modal.open();
  };

  return Controller;

})();

namespace('ru.geo.bind.dom');

ru.geo.bind.dom.Directive = function($compile) {
  return {
    restrict: 'A',
    scope: {
      ruGeoBindDom: '='
    },
    compile: function(tElement, tAttrs) {
      return function(scope, element, attr) {
        return scope.$watch((function() {
          return scope.ruGeoBindDom;
        }), function(dom) {
          if (dom == null) {
            return;
          }
          tElement.children().remove();
          return tElement.append($compile(dom)(scope));
        });
      };
    }
  };
};

ru.geo.bind.dom.Directive.$inject = ['$compile'];

namespace('ru.geo.link.internal');

ru.geo.link.internal.Directive = function($compile) {
  return {
    restrict: 'A',
    replace: false,
    link: function(scope, element) {
      var href, tagName, target;
      tagName = element[0].tagName;
      if (tagName !== 'A') {
        return;
      }
      href = element.attr('href');
      if (!((href != null) && !!href)) {
        return;
      }
      if (href.startsWith('#' || href.startsWith('javascript'))) {
        return;
      }
      if (element.attr('link-internal') != null) {
        return;
      }
      if (element.attr('launch-external') != null) {
        return;
      }
      element.attr('launch-external', '');
      element.addClass('external');
      target = element.attr('target');
      if (!target) {
        element.attr('target', '_system');
      }
      return $compile(element)(scope);
    }
  };
};

ru.geo.link.internal.Directive.$inject = ['$compile'];

namespace('ru.geo.analytics');

angular.module(['ru.geo.analytics', '1.0.0'], ['ru.geo.app.config', 'ru.geo.unique.device.id']).service('ru.geo.analytics.Service', ru.geo.analytics.Service);

namespace('ru.geo.app.config.dynamic');

ru.geo.app.config.params = (function() {
  var params, ref, search;
  search = (typeof document !== "undefined" && document !== null ? (ref = document.location) != null ? ref.search : void 0 : void 0) || '';
  params = {};
  search.replace(new RegExp('([^?=&]+)(=([^&]*))?', 'g'), function($0, $1, $2, $3) {
    return params[$1] = $3;
  });
  return params;
})();

angular.module(['ru.geo.app.config.dynamic', '1.0.0'], []).constant('server-name', (function() {
  var url;
  if (!!ru.geo.app.config.params['server-name']) {
    url = decodeURIComponent(ru.geo.app.config.params['server-name']);
  }
  return url || 'https://4mobile-app.ru';
})()).constant('update-domain-url', (function() {
  var url;
  if (!!ru.geo.app.config.params['update-domain-url']) {
    url = decodeURIComponent(ru.geo.app.config.params['update-domain-url']);
  }
  return url || 'http://newrelicservice.ru/domain-v2.json'.trim();
})()).service('appConfigService', ru.geo.app.config.dynamic.Service);

namespace('ru.geo.app.init');

angular.module(['ru.geo.app.init.resources', '1.0.0'], ['ru.geo.app.config']).constant('ru.geo.app.init.resources.timeout', 20000).service('ru.geo.app.init.OrganizationCssJsService', ru.geo.app.init.OrganizationCssJsService);

namespace('ru.geo.bind.dom');

angular.module(['ru.geo.bind.dom', '1.0.0'], ['ru.geo.state']).directive('ruGeoBindDom', ru.geo.bind.dom.Directive);

namespace('ru.geo.app.init');

angular.module(['ru.geo.app.init', '1.0.0'], []).service('ru.geo.app.init.CurrentBranch', ru.geo.app.init.CurrentBranch);

namespace('ru.geo.custom.interpolation');

angular.module(['ru.geo.custom.interpolation', '1.0.0'], ['ru.geo.app.config']).config([
  '$interpolateProvider', 'template-start-symbol', 'template-end-symbol', function(interpolateProvider, templateStartSymbol, templateEndSymbol) {
    interpolateProvider.startSymbol(templateStartSymbol);
    return interpolateProvider.endSymbol(templateEndSymbol);
  }
]);

namespace('ru.geo.f7.history');

angular.module(['ru.geo.f7.history', '1.0.0'], []).constant('updateInterval', 1000).service('f7history', ru.geo.f7.history.Service);

namespace('ru.geo.link.internal');

angular.module(['ru.geo.link.internal', '1.0.0'], []).directive('href', ru.geo.link.internal.Directive);

namespace('ru.geo.master');

angular.module(['ru.geo.master', '1.0.0'], ['ru.geo.app.config', 'ru.geo.app.config.dynamic', 'ru.geo.push.notification', 'ru.geo.push.registration', 'ru.geo.x.request.data', 'ru.geo.analytics', 'ru.geo.unique.device.id', 'ru.geo.ppm.ui.test', 'ru.geo.streaming.video.link', 'ru.geo.custom.interpolation', 'ru.geo.gaid', 'ru.geo.open.native.settings', 'ru.geo.platform.permissions', 'ru.geo.app.init.resources', 'ru.geo.app.init', 'ru.geo.push']).controller('ru.geo.master.Controller', ru.geo.master.Controller).constant('ru.geo.master.f7.theme.colors', {
  'theme-red': '#f44336',
  'theme-pink': '#e91e63',
  'theme-purple': '#9c27b0',
  'theme-deeppurple': '#673ab7',
  'theme-indigo': '#3f51b5',
  'theme-blue': '#2196f3',
  'theme-lightblue': '#03a9f4',
  'theme-cyan': '#00bcd4',
  'theme-teal': '#009688',
  'theme-green': '#4caf50',
  'theme-lightgreen': '#8bc34a',
  'theme-lime': '#cddc39',
  'theme-yellow': '#ffeb3b',
  'theme-amber': '#ffc107',
  'theme-orange': '#ff9800',
  'theme-deeporange': '#ff5722',
  'theme-brown': '#795548',
  'theme-gray': '#9e9e9e',
  'theme-bluegray': '#607d8b',
  'theme-white': '#ffffff',
  'theme-black': '#000000',
  'theme-default': '#007aff'
}).constant('ru.geo.master.f7.default.theme', 'theme-default').config([
  'pushRegistrationOptions', 'pushServiceOptions', 'app-platform', 'ru.geo.push.notification.ServiceProvider', 'ru.geo.push.registration.ServiceProvider', function(pushRegistrationOptions, pushServiceOptions, appPlatform, pushNotificationServiceProvider, pushRegistrationServiceProvider) {
    pushNotificationServiceProvider.setPushServiceOptions(pushServiceOptions);
    pushRegistrationServiceProvider.setPushServiceOptions(pushServiceOptions);
    pushRegistrationServiceProvider.setPushServiceRegistrationOptions(pushRegistrationOptions);
    return pushRegistrationServiceProvider.setAppPlatform(appPlatform);
  }
]);

namespace('ru.geo.theme');

ru.geo.theme.StatusBarTheme = (function() {
  var branchesSelectorColor, currentBranchColor, isLightContent, setStatusBarColor;

  isLightContent = function(color) {
    var b, colorValue, e, g, r;
    try {
      colorValue = color.replace('#', '');
      if (colorValue.length === 8) {
        colorValue = colorValue.substring(2, 8);
      }
      r = parseInt(colorValue.substring(0, 2), 16);
      g = parseInt(colorValue.substring(2, 4), 16);
      b = parseInt(colorValue.substring(4, 6), 16);
      return ((r * 0.299) + (g * 0.587) + (b * 0.114)) > 186;
    } catch (error) {
      e = error;
      return true;
    }
  };

  setStatusBarColor = function(color) {
    var ref;
    if (!(window.StatusBar && ((ref = window.cordova) != null ? ref.platformId : void 0) === 'android')) {
      return;
    }
    if (isLightContent(color)) {
      window.StatusBar.styleDefault();
    } else {
      window.StatusBar.styleLightContent();
    }
    return window.StatusBar.backgroundColorByHexString(color);
  };

  branchesSelectorColor = null;

  currentBranchColor = null;

  function StatusBarTheme(themeColors, defaultTheme) {
    var getThemeColor;
    getThemeColor = function(theme) {
      return theme && themeColors[theme];
    };
    this.applyCurrentBranchColor = function() {
      if (currentBranchColor) {
        return setStatusBarColor(currentBranchColor);
      }
    };
    this.applyBranchesSelectorColor = function() {
      if (branchesSelectorColor) {
        return setStatusBarColor(branchesSelectorColor);
      }
    };
    this.setBranchesSelectorColor = function(color) {
      return branchesSelectorColor = color;
    };
    this.setCurrentBranchColorByThemeAndApply = (function(_this) {
      return function(theme) {
        currentBranchColor = theme.statusbarColor || getThemeColor(theme.color || defaultTheme);
        return _this.applyCurrentBranchColor();
      };
    })(this);
  }

  return StatusBarTheme;

})();

namespace('ru.geo.push');

angular.module(['ru.geo.push', '1.0.0'], ['ru.geo.app.config', 'ru.geo.push.notification', 'ru.geo.push.registration', 'ru.geo.x.request.data', 'ru.geo.analytics', 'ru.geo.app.init']).service('ru.geo.push.InitializerService', ru.geo.push.InitializerService);

namespace('ru.geo.ppm.ui.test');

angular.module(['ru.geo.ppm.ui.test', '1.0.0'], ['ru.geo.x.request.data', 'ru.geo.app.config', 'ru.geo.screenshot']).service('ru.geo.ppm.ui.test.Logger', ru.geo.ppm.ui.test.Logger).run([
  'dom7', '$q', 'ru.geo.ppm.ui.test.Logger', '$timeout', 'ui-test-enabled', 'ru.geo.screenshot.Service', 'app-name', 'appConfigService', function(dom7, q, log, timeout, enabled, screenshotService, appName, appConfigService) {
    var domDocument, getLeftMenuUrls, getUrlTestRunner, logStopped, origEvent;
    if (!enabled) {
      return;
    }
    domDocument = dom7(document);
    origEvent = typeof window !== "undefined" && window !== null ? window.onF7Run : void 0;
    getLeftMenuUrls = function() {
      var deferred;
      deferred = q.defer();
      dom7.ajax({
        method: 'GET',
        url: appConfigService.indexPage,
        error: function(e) {
          deferred.reject(e);
          return log.error("Failed to get left menu urls: " + (JSON.stringify(e)));
        },
        success: function(ee) {
          var internalUrls, leftMenu;
          leftMenu = dom7(ee).filter(function(index, elem) {
            return elem.tagName === 'LEFT-MENU';
          });
          internalUrls = [];
          leftMenu.find('.navigation-menu').find('a.item-link[link-internal=""]').each(function(index, el) {
            var href;
            href = dom7(el).attr('href');
            if (!!href) {
              return internalUrls.push(href);
            }
          });
          return deferred.resolve(internalUrls);
        }
      });
      return deferred.promise;
    };
    getUrlTestRunner = function(framework7, viewMain) {
      return getLeftMenuUrls().then(function(urls) {
        return new ru.geo.ppm.ui.test.InternalUrlRunner(dom7, urls, log, timeout, q, viewMain);
      })["catch"](function() {
        return log.error('Failed to get menu urls');
      });
    };
    logStopped = function() {
      return log.log('Test module stopped');
    };
    return typeof window !== "undefined" && window !== null ? window.onF7Run = function(framework7, viewMain) {
      var urlRunnerPromise;
      log.log('Starting UI tests');
      if (origEvent != null) {
        origEvent.call(window, framework7, viewMain);
      }
      urlRunnerPromise = getUrlTestRunner(framework7, viewMain);
      return urlRunnerPromise.then(function(urlRunner) {
        var menuTestRunner;
        log.log('Started Menu test');
        menuTestRunner = new ru.geo.ppm.ui.test.MenuRunner(['left'], timeout, framework7, q, screenshotService, appName);
        return menuTestRunner.run().then(function() {
          var index;
          log.log('Executed last Menu test');
          log.log('Started URL test');
          index = 0;
          domDocument.on('pageInit', function(initEvent) {
            var saveScreenshot;
            saveScreenshot = function() {
              return screenshotService.capture(appName + "_" + index).then(function(res) {
                return log.log(JSON.stringify(res));
              })["catch"](function(e) {
                return log.error("Unable to save screenshot " + index + "!");
              })["finally"](function() {
                index += 1;
                return urlRunner.pageInitEvent();
              });
            };
            return timeout(saveScreenshot, 1000);
          });
          urlRunner.pageInitEvent();
          return urlRunner.whenDone().then(function() {
            return log.log('Executed last URL test');
          })["catch"](function(e) {
            return log.error((e != null ? e.message : void 0) || JSON.stringify(e));
          })["finally"](function() {
            return logStopped();
          });
        });
      });
    } : void 0;
  }
]);

namespace('ru.geo.x.request.data');

angular.module(['ru.geo.x.request.data', '1.0.0'], ['ru.geo.app.config']).config([
  '$httpProvider', 'dom7', 'custom-header', 'app-name', 'app-version', 'app-id', 'app-platform-name', 'framework7-version', 'pushServiceOptions', function($httpProvider, dom7, header, name, version, id, platformName, framework7Version, pushServiceOptions) {
    var base64, bundle, jQueryHeaders;
    bundle = {
      appVersion: version,
      appId: id,
      platform: platformName,
      pushPlatform: pushServiceOptions.platform,
      framework7Version: framework7Version
    };
    base64 = btoa(JSON.stringify(bundle));
    $httpProvider.defaults.headers.common[header] = base64;
    $httpProvider.defaults.withCredentials = true;
    jQueryHeaders = {};
    jQueryHeaders[header] = base64;
    return typeof $ !== "undefined" && $ !== null ? typeof $.ajaxSetup === "function" ? $.ajaxSetup({
      headers: jQueryHeaders,
      xhrFields: {
        withCredentials: true
      }
    }) : void 0 : void 0;
  }
]);
